==> kubernetes-model-storageclass-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/storage/CSIDriverBuilder.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CSIDriverBuilder extends io.fabric8.kubernetes.api.model.storage.CSIDriverFluentImpl<io.fabric8.kubernetes.api.model.storage.CSIDriverBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.CSIDriver,io.fabric8.kubernetes.api.model.storage.CSIDriverBuilder>{
  public CSIDriverBuilder() {
    this(false);
  }
  public CSIDriverBuilder(java.lang.Boolean validationEnabled) {
    this(new CSIDriver(), validationEnabled);
  }
  public CSIDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSIDriverFluent<?> fluent) {
    this(fluent, false);
  }
  public CSIDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSIDriverFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CSIDriver(), validationEnabled);
  }
  public CSIDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSIDriverFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.CSIDriver instance) {
    this(fluent, instance, false);
  }
  public CSIDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSIDriverFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.CSIDriver instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSIDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSIDriver instance) {
    this(instance,false);
  }
  public CSIDriverBuilder(io.fabric8.kubernetes.api.model.storage.CSIDriver instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.CSIDriverFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.CSIDriver build() {
    CSIDriver buildable = new CSIDriver(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CSIDriverBuilder that = (CSIDriverBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/storage/CSIDriverBuilder.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CSIDriverBuilder extends CSIDriverFluentImpl<CSIDriverBuilder> implements VisitableBuilder<CSIDriver,CSIDriverBuilder>{
  public CSIDriverBuilder() {
    this(false);
  }
  public CSIDriverBuilder(Boolean validationEnabled) {
    this(new CSIDriver(), validationEnabled);
  }
  public CSIDriverBuilder(CSIDriverFluent<?> fluent) {
    this(fluent, false);
  }
  public CSIDriverBuilder(CSIDriverFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CSIDriver(), validationEnabled);
  }
  public CSIDriverBuilder(CSIDriverFluent<?> fluent,CSIDriver instance) {
    this(fluent, instance, false);
  }
  public CSIDriverBuilder(CSIDriverFluent<?> fluent,CSIDriver instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CSIDriverBuilder(CSIDriver instance) {
    this(instance,false);
  }
  public CSIDriverBuilder(CSIDriver instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CSIDriverFluent<?> fluent;
  Boolean validationEnabled;
  public CSIDriver build() {
    CSIDriver buildable = new CSIDriver(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
